import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:zhiying_base_widget/pages/message_notice_page/bloc/message_notice_bloc.dart';
import 'package:zhiying_base_widget/pages/message_notice_page/bloc/message_notice_repository.dart';
import 'package:zhiying_comm/zhiying_comm.dart';

///
/// 消息通知页
///
class MessageNoticePage extends StatelessWidget {
  final Map<String, dynamic> data;

  MessageNoticePage(this.data);

  @override
  Widget build(BuildContext context) {
    return BlocProvider<MessageNoticeBloc>(
      create: (_) => MessageNoticeBloc(MessageNoticeRepository())..add(MessageNoticeInitEvent()),
      child: _MessageNoticePageContainer(),
    );
  }
}

class _MessageNoticePageContainer extends StatefulWidget {
  @override
  __MessageNoticePageContainerState createState() => __MessageNoticePageContainerState();
}

class __MessageNoticePageContainerState extends State<_MessageNoticePageContainer> {
  @override
  Widget build(BuildContext context) {
    return _buildMainWidget();
  }

  /// 主视图
  Widget _buildMainWidget() {
    return Scaffold(
        appBar: _buildAppBarWidget(),
        backgroundColor: HexColor.fromHex('#F9F9F9'),
        body: ListView.builder(
            padding: const EdgeInsets.only(left: 12.5, right: 12.5, top: 8),
            // shrinkWrap: true,
            itemCount: 5,
            itemBuilder: (context, index) {
              return _buildOfficialActivitiesStyleWidget();
            }));
  }

  /// 消息中心样式
  Widget _buildMessageCenterStyleWidget(int index, int length) {
    var borderRadius = index == 0
        ? BorderRadius.only(topLeft: Radius.circular(7.5), topRight: Radius.circular(7.5))
        : index == length - 1 ? BorderRadius.only(bottomRight: Radius.circular(7.5), bottomLeft: Radius.circular(7.5)) : BorderRadius.only();

    return Container(
      decoration: BoxDecoration(color: HexColor.fromHex('#FFFFFF'), borderRadius: borderRadius),
      padding: const EdgeInsets.only(left: 15, right: 15, top: 16),
      child: Column(
        children: <Widget>[
          Container(
            height: 30,
            width: double.infinity,
            child: Row(
              children: <Widget>[
                _buildCustomerAvatarWidget(),
                const SizedBox(width: 10),
                Expanded(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      /// 官方活动
                      Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: <Widget>[
                          Text('官方活动', style: TextStyle(color: HexColor.fromHex('#333333'), fontWeight: FontWeight.bold, fontSize: 13)),
                          Text('04-20 16:00', style: TextStyle(color: HexColor.fromHex('#D8D8D8'), fontSize: 12)),
                        ],
                      ),
                      Padding(
                        padding: const EdgeInsets.only(right: 22),
                        child: Text(
                          '2020年6月23日4:00至6月30日4:00关闭提现aaa',
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(color: HexColor.fromHex('#999999'), fontSize: 12),
                        ),
                      ),
                    ],
                  ),
                )
              ],
            ),
          ),
          Padding(padding: const EdgeInsets.only(top: 14.5), child: Divider(height: 0.5, color: HexColor.fromHex('#EFEFEF')))
        ],
      ),
    );
  }

  /// 官方通知样式
  Widget _buildOfficialNoticeStyleWidget() {
    return Container(
      padding: const EdgeInsets.only(left: 15, right: 15, top: 12.5, bottom: 10),
      margin: const EdgeInsets.only(bottom: 7.5),
      decoration: BoxDecoration(
        color: HexColor.fromHex('#FFFFFF'),
        borderRadius: BorderRadius.circular(7.5),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              _buildCustomerAvatarWidget(),
              const SizedBox(width: 10),
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    /// 标题
                    Text('关于关闭提现功能通知', style: TextStyle(color: HexColor.fromHex('#333333'), fontSize: 14, fontWeight: FontWeight.bold)),
                    const SizedBox(height: 5),

                    /// 内容
                    Text('由于微信官方的限制，我们暂时将嗨如意小程序内的提现功能进行关闭并进行维护，关闭功能时间为2020年6月23日4:00至6月30日4:00，请谅解',
                        maxLines: 3, overflow: TextOverflow.ellipsis, style: TextStyle(color: HexColor.fromHex('#999999'), fontSize: 11))
                  ],
                ),
              )
            ],
          ),

          /// 时间
          Padding(padding: const EdgeInsets.only(top: 16), child: Text('2020-06-23 01:00:06', style: TextStyle(color: HexColor.fromHex('#D8D8D8'), fontSize: 11)))
        ],
      ),
    );
  }

  /// 官方活动样式
  Widget _buildOfficialActivitiesStyleWidget() {
    return Container(
      padding: const EdgeInsets.only(left: 15, right: 15, top: 12.5, bottom: 10),
      margin: const EdgeInsets.only(bottom: 7.5),
      decoration: BoxDecoration(borderRadius: BorderRadius.circular(7.5), color: HexColor.fromHex('#FFFFFF')),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          /// 标题
          Text(
            '8.8淘宝会员节大促',
            style: TextStyle(color: HexColor.fromHex('#333333'), fontWeight: FontWeight.bold, fontSize: 14),
            maxLines: 1,
            overflow: TextOverflow.ellipsis,
          ),
          const SizedBox(height: 6),

          /// 图片海报
          ClipRRect(
            borderRadius: BorderRadius.circular(7.5),
              child: CachedNetworkImage(imageUrl: 'http://ossq.izhyin.cn/index_carousel_1.png', width: double.infinity, )),
          const SizedBox(height: 6.5),

          /// 活动内容
          Text(
            '京东家电815周年庆，全场家电最低五折起，买一送一等超多优惠活动，点击查看活动详情',
            maxLines: 2,
            overflow: TextOverflow.ellipsis,
            style: TextStyle(fontSize: 11, color: HexColor.fromHex('#999999')),
          ),

          /// 时间
          const SizedBox(height: 7),
          Text('2020-06-23 01:00:06', style: TextStyle(color: HexColor.fromHex('#D8D8D8'), fontSize: 11))
        ],
      ),
    );
  }

  /// 交易通知样式
  Widget _buildTradeNoticeStyleWidget() {
    return Container(
      padding: const EdgeInsets.only(left: 15, right: 15, top: 12.5, bottom: 10),
      margin: const EdgeInsets.only(bottom: 7.5),
      decoration: BoxDecoration(
        color: HexColor.fromHex('#FFFFFF'),
        borderRadius: BorderRadius.circular(7.5),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              _buildCustomerAvatarWidget(),
              const SizedBox(width: 10),
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    /// 标题
                    Text('自购订单收益', style: TextStyle(color: HexColor.fromHex('#333333'), fontSize: 14, fontWeight: FontWeight.bold)),
                    const SizedBox(height: 5),

                    /// 内容
                    _buildCustomerTradeContentWidget(),
                  ],
                ),
              )
            ],
          ),

          /// 时间
          Padding(padding: const EdgeInsets.only(top: 16), child: Text('2020-06-23 01:00:06', style: TextStyle(color: HexColor.fromHex('#D8D8D8'), fontSize: 11)))
        ],
      ),
    );
  }

  /// 推广通知样式
  Widget _buildPromoteNoticeStyleWidget() {
    return Container(
      padding: const EdgeInsets.only(left: 15, right: 15, top: 12.5, bottom: 10),
      margin: const EdgeInsets.only(bottom: 7.5),
      decoration: BoxDecoration(
        color: HexColor.fromHex('#FFFFFF'),
        borderRadius: BorderRadius.circular(7.5),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              _buildCustomerAvatarWidget(),
              const SizedBox(width: 10),
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    /// 标题
                    Text('新增直推粉丝', style: TextStyle(color: HexColor.fromHex('#333333'), fontSize: 14, fontWeight: FontWeight.bold)),
                    const SizedBox(height: 5),

                    /// 内容
                    Text('恭喜您成功邀请152****5887加入您的团队，快带领小伙伴走向致富之路吧！',
                        maxLines: 3, overflow: TextOverflow.ellipsis, style: TextStyle(color: HexColor.fromHex('#999999'), fontSize: 11))
                  ],
                ),
              )
            ],
          ),

          /// 时间
          Padding(padding: const EdgeInsets.only(top: 16), child: Text('2020-06-23 01:00:06', style: TextStyle(color: HexColor.fromHex('#D8D8D8'), fontSize: 11)))
        ],
      ),
    );
  }

  /// 反馈通知样式
  Widget _buildFeedbackNoticeStyleWidget() {
    return Container(
      padding: const EdgeInsets.only(left: 15, right: 15, top: 14, bottom: 10),
      margin: const EdgeInsets.only(bottom: 7.5),
      decoration: BoxDecoration(
        color: HexColor.fromHex('#FFFFFF'),
        borderRadius: BorderRadius.circular(7.5),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              _buildCustomerAvatarWidget(),
              const SizedBox(width: 10),
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    /// 标题
                    Text('您的反馈有回复啦', style: TextStyle(color: HexColor.fromHex('#333333'), fontSize: 14, fontWeight: FontWeight.bold)),
                    const SizedBox(height: 3),
                    /// 内容
                    Text('点击查看回复详情',
                        maxLines: 1, overflow: TextOverflow.ellipsis, style: TextStyle(color: HexColor.fromHex('#999999'), fontSize: 11))
                  ],
                ),
              )
            ],
          ),

          /// 时间
          Padding(padding: const EdgeInsets.only(top: 16), child: Text('2020-06-23 01:00:06', style: TextStyle(color: HexColor.fromHex('#D8D8D8'), fontSize: 11)))
        ],
      ),
    );
  }

  /// APPBar
  Widget _buildAppBarWidget() {
    return AppBar(
      leading: IconButton(
        icon: Icon(
          Icons.arrow_back_ios,
          size: 22,
          color: HexColor.fromHex('#333333'),
        ),
        onPressed: () => Navigator.maybePop(context),
      ),
      title: Text(
        '消息中心',
        style: TextStyle(color: HexColor.fromHex('#333333'), fontSize: 15, fontWeight: FontWeight.bold),
      ),
      centerTitle: true,
      backgroundColor: HexColor.fromHex('#FFFFFF'),
      elevation: 0,
    );
  }

  /// ================================= 自定义View ================================= ///
  Widget _buildCustomerAvatarWidget() {
    return Container(
      // width: 30,
      // height: 30,
      child: Stack(
        alignment: AlignmentDirectional.topEnd,
        // mainAxisAlignment: MainAxisAlignment.start,
        // crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Container(
            height: 30,
            width: 30,
            color: Colors.deepPurpleAccent,
          ),
          Transform.translate(
            offset: Offset(5, -4.5),
            child: Container(
              // width: 17,
              height: 12,
              padding: const EdgeInsets.only(left: 3, right: 3, top: 1, bottom: 1),
              alignment: Alignment.center,
              decoration:
                  BoxDecoration(color: HexColor.fromHex('#FF4242'), borderRadius: BorderRadius.circular(6), border: Border.all(color: HexColor.fromHex('#FFFFFF'), width: 0.5)),
              child: Text(
                '18',
                textAlign: TextAlign.center,
                style: TextStyle(fontSize: 9, color: HexColor.fromHex('#FFFFFF')),
              ),
            ),
          )
        ],
      ),
    );
  }

  Widget _buildCustomerTradeContentWidget(){
    Map<String, String> datas= {
      '订单编号：':'154547896541651464788',
      '订单类型：':'京东',
      '预估收益：': '8.00',
      '下单时间：':'2020-08-14 11:35:39',
      '预估结算：':'次月25日结算',
    };
    List<Widget> lists = [];
    datas.forEach((key, value) { 
      lists.add(Padding(
        padding: const EdgeInsets.only(bottom: 5),
        child: RichText(
          textAlign: TextAlign.start,
          text: TextSpan(
            children: [
              TextSpan(text: key, style: TextStyle(fontSize: 11, color: HexColor.fromHex('#999999'))),
              TextSpan(text: value, style: TextStyle(fontSize: 11, color: HexColor.fromHex('#999999'))),
            ]
          ),
        ),
      ));
    });
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: lists,
    );
  }
}
